@@ -2,7 +2,7 @@
 #
 # Author: Yipeng Sun <syp at umd dot edu>
 # License: BSD 2-clause
-# Last Change: Tue Sep 22, 2020 at 02:34 AM +0800
+# Last Change: Fri Jan 15, 2021 at 12:21 AM +0100
 """
 This module provides basic infrastructure for ntuple related C++ code
 generation.
@@ -12,7 +12,6 @@ import abc
 import yaml
 import subprocess
 
-from collections import namedtuple
 from shutil import which
 from os import path
 
@@ -71,15 +70,13 @@ class UniqueList(list):
 
 def load_file(filepath, current_file_path=__file__):
     """
-    Return relative path based on current file directory if ``filepath`` starts
-    with ``!:``.
+    Return relative path based on current file directory if ``filepath`` is
+    enclosed with ``<>``, otherwise return ``filepath`` verbatim.
     """
-    if filepath.startswith('!:'):
-        filepath = filepath[2:]
+    if filepath[0] == '<' and filepath[-1] == '>':
         return path.join(path.abspath(path.dirname(current_file_path)),
-                         filepath)
-    else:
-        return filepath
+                         filepath[1:-1])
+    return filepath
 
 
 def update_config(config, update, merge=True):
@@ -90,17 +87,27 @@ def update_config(config, update, merge=True):
     Else merge the value from two keys if ``merge`` key argument is set to
     ``True``.
     """
+    result = {}
+    for key, value in config.items():
+        if key in update and merge:
+            if isinstance(value, dict):
+                result[key] = update_config(value, update[key])
+            elif isinstance(value, list):
+                result[key] = value+update[key]
+            else:
+                result[key] = update[key]
+
+        elif key in update:
+            result[key] = update[key]
+
+        else:
+            result[key] = value
+
     for key, value in update.items():
         if key not in config:
-            config[key] = value
-        elif merge:
-            if isinstance(value, dict):
-                config[key].update(value)
-            else:
-                config[key] += value
+            result[key] = value
 
-
-Variable = namedtuple('Variable', 'type name rvalue', defaults=(None,))
+    return result
 
 
 ##############
